﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace FriskaDama
{
    class AI
    {
        public static Random random = new Random();
        public bool Modra { get; private set; }

        public AI (bool modra)
        {
            this.Modra = modra;
        }

        public Tah Tah(int hloubka)
        {
            Tah[] ohodnoceneMozneTahy = OhodnoceneMozneTahy(hloubka);
            if (ohodnoceneMozneTahy.Length > 0)
            {
                // Načtení tahů s největší hodnotou
                Tah[] bestTahy = TahySNejvetsiHodnotou(ohodnoceneMozneTahy);

                // Vybrání náhodně z nejlepších tahů
                int bestTahyInt = random.Next(bestTahy.Length);
                Tah tah = bestTahy[bestTahyInt];
                return tah;
            }
            return null;
        }

        Tah[] OhodnoceneMozneTahy(int hloubka)
        {
            // Načtení všech možných tahů
            Tah[] mozneTahy = MozneTahy();

            // Ohodnocení útoku a přesunu 
            foreach (Tah moznyTah in mozneTahy)
            {
                if (hloubka > 0)
                {
                    OhodnotUtok(moznyTah);
                    OhodnotTah(moznyTah);
                    Hra.PresunFigurkyVAl(moznyTah);
                    AI enemy = new AI(!Modra);
                    Tah enemyTah = enemy.Tah(hloubka - 1);
                    if (enemyTah != null)
                    {
                        moznyTah.Hodnota -= enemyTah.Hodnota;
                    }
                    Hra.ObnovStav();
                }
                else
                {
                    OhodnotUtok(moznyTah);
                    OhodnotTah(moznyTah);
                }

            }
            return mozneTahy;
        }

        /// <summary>
        /// Ohodnotí tah, kdy při přesunu sebere figurku
        /// </summary>
        /// <param name="polickoSFigurkou"></param>
        /// <returns></returns>
        public int OhodnotUtok(Tah moznyTah)
        {
            int hodnota = 0;
            foreach (Tah nepratelskaFigurkaPolicko in moznyTah.AktualniPolicko.Figurka.MozneUtoky())
            {
                moznyTah.Hodnota += nepratelskaFigurkaPolicko.BudouciPolicko.Figurka.Hodnota;
                hodnota += nepratelskaFigurkaPolicko.BudouciPolicko.Figurka.Hodnota;
            }
            return hodnota;
        }

        /// <summary>
        /// Ohodnotí tah, kdy při přesunu se figurka postaví na poslední řádek
        /// </summary>
        /// <param name="moznyTah"></param>
        /// <returns></returns>
        public int OhodnotTah(Tah moznyTah)
        {
            int hodnota = 0;
            bool modra = moznyTah.AktualniPolicko.Figurka.Modra;
            if(modra && moznyTah.AktualniPolicko.Figurka is Kamen && moznyTah.BudouciPolicko.Souradnice.Radek == 0)
            {
                moznyTah.Hodnota += 3;
                hodnota += 3;
            }
            if(!modra && moznyTah.AktualniPolicko.Figurka is Kamen && moznyTah.BudouciPolicko.Souradnice.Radek == 9)
            {
                hodnota+=3;
            }
            return hodnota;
        }

        /// <summary>
        /// Vrátí všechny možné tahy přátelských figurek
        /// </summary>
        /// <returns></returns>
        Tah[] MozneTahy()
        {
            List<Tah> mozneTahy = new List<Tah>();
            foreach (Policko polickoSFigurkou in Hra.ZjistiPolickaSFigurkami(Modra))
            {
                mozneTahy.InsertRange(mozneTahy.Count, polickoSFigurkou.Figurka.MozneTahy());
            }
            return mozneTahy.ToArray();
        }

        Tah[] TahySNejvetsiHodnotou(Tah[] tahy)
        {
            // Načtení tahů s největší hodnotou
            List<Tah> bestTahy = new List<Tah>();
            bestTahy.Add(tahy[0]);
            for (int i = 1; i < tahy.Length; i++)
            {
                if (tahy[i].Hodnota > bestTahy[0].Hodnota)
                {
                    bestTahy = new List<Tah>();
                    bestTahy.Add(tahy[i]);
                }
                else if (tahy[i].Hodnota == bestTahy[0].Hodnota)
                {
                    bestTahy.Add(tahy[i]);
                }
            }
            return bestTahy.ToArray();
        }
    }
}
