﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace FriskaDama
{
    static class Hra
    {
        /// <summary>
        /// Kolekce políček šachovnice
        /// </summary>
        public static Policko[,] PolickaHraciDesky { get; private set; }
        public static bool ModraNaTahu { get; set; }
        public static bool KonecHry { get; private set; }
        public static int Kolo { get; private set; }
        public static int VyhozenaModraFigurka { get; set; }
        public static int VyhozenaCervenaFigurka { get; set; }
        static MainWindow mainWindow;

        static Hra()
        {
            ModraNaTahu = true;
        }

        /// <summary>
        /// Spustí novou hru, vymaže staré figurky i políčka a vytvoří nové figurky i políčka
        /// </summary>
        /// <param name="mainWindow"></param>
        public static void NovaHra(MainWindow mainWindow)
        {
            Hra.mainWindow = mainWindow;
            Kolo = 1;

            PolickaHraciDesky = new Policko[10, 10];
            ModraNaTahu = true;
            KonecHry = false;
            VyhozenaCervenaFigurka = 0;
            VyhozenaModraFigurka = 0;
            Kolo = 1;
            mainWindow.grid.Children.RemoveRange(0, mainWindow.grid.Children.Count);
            mainWindow.statusTextBlock.Text = Kolo.ToString() + " kolo";
            mainWindow.modreTextBlock.Text = "Žádná figurka nebyla sebrána.";
            mainWindow.cerveneTextBlock.Text = "Žádná figurka nebyla sebrána.";
            mainWindow.naTahuTextBlock.Text = "Na tahu jsou modré figurky.";

            // Vytvoření matice z tlačítek
            for (int i = 0; i < 10; i++)
            {
                for (int j = 0; j < 10; j++)
                {
                    // Vytvoření a nastavení tlačítka
                    Button tlacitko = new Button();
                    tlacitko.SetValue(Grid.ColumnProperty, j);
                    tlacitko.SetValue(Grid.RowProperty, i);
                    tlacitko.SetValue(Border.BorderThicknessProperty, new Thickness(0));
                    tlacitko.Focusable = false;
                    tlacitko.Padding = new Thickness(0);

                    mainWindow.grid.Children.Add(tlacitko);
                    PolickaHraciDesky[i, j] = new Policko(tlacitko, new Souradnice(i, j));
                }
            }
            // Vytvoření hracích figurek
            for (int i = 0; i < 4; i++)
                for (int j = (i + 1) % 2; j < 10; j += 2)
                    PolickaHraciDesky[i, j].Figurka = new Kamen(false, PolickaHraciDesky[i, j].Souradnice);

            for (int i = 6; i < 10; i++)
                for (int j = (i + 1) % 2; j < 10; j += 2)
                    PolickaHraciDesky[i, j].Figurka = new Kamen(true, PolickaHraciDesky[i, j].Souradnice);
        }

        /// <summary>
        /// Přesun figurky
        /// </summary>
        /// <param name="aktualniPolicko">Políčko, na kterém se přesouvaná figurka nachází</param>
        /// <param name="budouciPolicko">Políčko, na kterém se přesouvaná figurka bude nacházet</param>
        public static void PresunFigurky(Tah tah)
        {
            if (tah.AktualniPolicko.Figurka is Kamen)
            {
                if (tah.AktualniPolicko.Figurka.Modra == true)
                {
                    if (tah.BudouciPolicko.Souradnice.Radek != 0)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Kamen(true, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    if (tah.BudouciPolicko.Souradnice.Radek == 0)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(true, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                    if (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 1)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka.Modra == false)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka = null;
                            VyhozenaCervenaFigurka++;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka.Modra == false)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka = null;
                            VyhozenaCervenaFigurka++;
                        }
                    }
                }
                if (tah.AktualniPolicko.Figurka.Modra == false)
                {
                    if (tah.BudouciPolicko.Souradnice.Radek != 9)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Kamen(false, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    if (tah.BudouciPolicko.Souradnice.Radek == 9)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(false, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                    if (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 1)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka.Modra == true)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka = null;
                            VyhozenaModraFigurka++;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka.Modra == true)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka = null;
                            VyhozenaModraFigurka++;
                        }
                    }
                    Kolo++;
                }

            }
            else
            {
                PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(tah.AktualniPolicko.Figurka.Modra, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);

                // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                // Označí řádek
                if (tah.AktualniPolicko.Souradnice.Radek == tah.BudouciPolicko.Souradnice.Radek && (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 2))
                {
                    if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                    {
                        for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 2; i <= tah.AktualniPolicko.Souradnice.Sloupec - 2; i += 2)
                        {
                            if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka != null)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka.Modra == true)
                                {
                                    VyhozenaModraFigurka++;
                                }
                                else
                                {
                                    VyhozenaCervenaFigurka++;
                                }
                                PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka = null;
                            }
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                    {
                        for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 2; i <= tah.BudouciPolicko.Souradnice.Sloupec - 2; i += 2)
                        {
                            if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka != null)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka.Modra == true)
                                {
                                    VyhozenaModraFigurka++;
                                }
                                else
                                {
                                    VyhozenaCervenaFigurka++;
                                }
                                PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka = null;
                            }
                        }
                    }
                }
                // Označí sloupec
                if (tah.AktualniPolicko.Souradnice.Sloupec == tah.BudouciPolicko.Souradnice.Sloupec && (Math.Abs(tah.AktualniPolicko.Souradnice.Sloupec - tah.BudouciPolicko.Souradnice.Sloupec) != 2))
                {
                    if (tah.AktualniPolicko.Souradnice.Radek > tah.BudouciPolicko.Souradnice.Radek)
                    {
                        for (int i = tah.BudouciPolicko.Souradnice.Radek + 2; i <= tah.AktualniPolicko.Souradnice.Radek - 2; i += 2)
                        {
                            if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka != null)
                            {
                                if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka.Modra == true)
                                {
                                    VyhozenaModraFigurka++;
                                }
                                else
                                {
                                    VyhozenaCervenaFigurka++;
                                }
                                PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka = null;
                            }
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Radek < tah.BudouciPolicko.Souradnice.Radek)
                    {
                        for (int i = tah.AktualniPolicko.Souradnice.Radek + 2; i <= tah.BudouciPolicko.Souradnice.Radek - 2; i += 2)
                        {
                            if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka != null)
                            {
                                if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka.Modra == true)
                                {
                                    VyhozenaModraFigurka++;
                                }
                                else
                                {
                                    VyhozenaCervenaFigurka++;
                                }
                                PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka = null;
                            }
                        }
                    }
                }
                // Označí ortogonální pohyb
                int pricist = 1;
                if (tah.AktualniPolicko.Souradnice.Sloupec != tah.BudouciPolicko.Souradnice.Sloupec && tah.AktualniPolicko.Souradnice.Radek != tah.BudouciPolicko.Souradnice.Radek && (Math.Abs(tah.AktualniPolicko.Souradnice.Sloupec - tah.BudouciPolicko.Souradnice.Sloupec) != 1))
                {
                    if (tah.AktualniPolicko.Souradnice.Radek < tah.BudouciPolicko.Souradnice.Radek)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 1; i <= tah.BudouciPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka.Modra == true)
                                    {
                                        VyhozenaModraFigurka++;
                                    }
                                    else
                                    {
                                        VyhozenaCervenaFigurka++;
                                    }
                                    PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 1; i <= tah.AktualniPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka.Modra == true)
                                    {
                                        VyhozenaModraFigurka++;
                                    }
                                    else
                                    {
                                        VyhozenaCervenaFigurka++;
                                    }
                                    PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Radek > tah.BudouciPolicko.Souradnice.Radek)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 1; i <= tah.BudouciPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka.Modra == true)
                                    {
                                        VyhozenaModraFigurka++;
                                    }
                                    else
                                    {
                                        VyhozenaCervenaFigurka++;
                                    }
                                    PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 1; i <= tah.AktualniPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka.Modra == true)
                                    {
                                        VyhozenaModraFigurka++;
                                    }
                                    else
                                    {
                                        VyhozenaCervenaFigurka++;
                                    }
                                    PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                    }
                }

                if (tah.AktualniPolicko.Figurka.Modra == false)
                {
                    Kolo++;
                }
            }
            // Odstraní figurku z aktualního políčka, která byla přiřazena budoucímu políčku
            tah.AktualniPolicko.Figurka = null;

            // Nastavení informace, kdo je na tahu
            ModraNaTahu = !ModraNaTahu;
            if (ModraNaTahu)
            {
                mainWindow.naTahuTextBlock.Text = "Na tahu jsou modré figurky.";
            }
            else
            {
                mainWindow.naTahuTextBlock.Text = "Na tahu jsou červené figurky.";
            }

            mainWindow.statusTextBlock.Text = Kolo.ToString() + " kolo";

            if (VyhozenaModraFigurka >= 1)
            {
                mainWindow.modreTextBlock.Text = VyhozenaModraFigurka.ToString();
                if (VyhozenaModraFigurka == 20)
                {
                    mainWindow.statusTextBlock.Text = "Vyhrála červená figurka";
                    KonecHry = true;
                }
            }

            if (VyhozenaCervenaFigurka >= 1)
            {
                mainWindow.cerveneTextBlock.Text = VyhozenaCervenaFigurka.ToString();
                if (VyhozenaCervenaFigurka == 20)
                {
                    mainWindow.statusTextBlock.Text = "Vyhrála modrá figurka";
                    KonecHry = true;
                }
            }
        }

        /// <summary>
        /// Přesun figurky uvnitř Al
        /// </summary>
        /// <param name="aktualniPolicko">Políčko, na kterém se přesouvaná figurka nachází</param>
        /// <param name="budouciPolicko">Políčko, na kterém se přesouvaná figurka bude nacházet</param>
        public static void PresunFigurkyVAl(Tah tah)
        {
            if (tah.AktualniPolicko.Figurka is Kamen)
            {
                if (tah.AktualniPolicko.Figurka.Modra == true)
                {
                    if (tah.BudouciPolicko.Souradnice.Radek != 0)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Kamen(true, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    if (tah.BudouciPolicko.Souradnice.Radek == 0)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(true, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                    if (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 1)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka.Modra == false)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka = null;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka.Modra == false)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek - 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka = null;
                        }
                    }
                }
                if (tah.AktualniPolicko.Figurka.Modra == false)
                {
                    if (tah.BudouciPolicko.Souradnice.Radek != 9)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Kamen(false, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    if (tah.BudouciPolicko.Souradnice.Radek == 9)
                    {
                        PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(false, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);
                    }
                    // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                    if (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 1)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka.Modra == true)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec + 1].Figurka = null;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec && PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka != null && Hra.PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka.Modra == true)
                        {
                            PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + 1, tah.AktualniPolicko.Souradnice.Sloupec - 1].Figurka = null;
                        }
                    }
                }

            }
            else
            {
                PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Figurka = new Dama(tah.AktualniPolicko.Figurka.Modra, PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek, tah.BudouciPolicko.Souradnice.Sloupec].Souradnice);

                // Zjistí, jestli se přeskočila soupeřova figurka, tu pak odstraní
                // Označí řádek
                if (tah.AktualniPolicko.Souradnice.Radek == tah.BudouciPolicko.Souradnice.Radek && (Math.Abs(tah.AktualniPolicko.Souradnice.Radek - tah.BudouciPolicko.Souradnice.Radek) != 2))
                {
                    if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                    {
                        for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 2; i <= tah.AktualniPolicko.Souradnice.Sloupec - 2; i += 2)
                        {
                            if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka != null)
                            {
                                PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka = null;
                            }
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                    {
                        for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 2; i <= tah.BudouciPolicko.Souradnice.Sloupec - 2; i += 2)
                        {
                            if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka != null)
                            {
                                PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek, i].Figurka = null;
                            }
                        }
                    }
                }
                // Označí sloupec
                if (tah.AktualniPolicko.Souradnice.Sloupec == tah.BudouciPolicko.Souradnice.Sloupec && (Math.Abs(tah.AktualniPolicko.Souradnice.Sloupec - tah.BudouciPolicko.Souradnice.Sloupec) != 2))
                {
                    if (tah.AktualniPolicko.Souradnice.Radek > tah.BudouciPolicko.Souradnice.Radek)
                    {
                        for (int i = tah.BudouciPolicko.Souradnice.Radek + 2; i <= tah.AktualniPolicko.Souradnice.Radek - 2; i += 2)
                        {
                            if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka != null)
                            {
                                PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka = null;
                            }
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Radek < tah.BudouciPolicko.Souradnice.Radek)
                    {
                        for (int i = tah.AktualniPolicko.Souradnice.Radek + 2; i <= tah.BudouciPolicko.Souradnice.Radek - 2; i += 2)
                        {
                            if (PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka != null)
                            {
                                PolickaHraciDesky[i, tah.AktualniPolicko.Souradnice.Sloupec].Figurka = null;
                            }
                        }
                    }
                }
                // Označí ortogonální pohyb
                int pricist = 1;
                if (tah.AktualniPolicko.Souradnice.Sloupec != tah.BudouciPolicko.Souradnice.Sloupec && tah.AktualniPolicko.Souradnice.Radek != tah.BudouciPolicko.Souradnice.Radek && (Math.Abs(tah.AktualniPolicko.Souradnice.Sloupec - tah.BudouciPolicko.Souradnice.Sloupec) != 1))
                {
                    if (tah.AktualniPolicko.Souradnice.Radek < tah.BudouciPolicko.Souradnice.Radek)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 1; i <= tah.BudouciPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 1; i <= tah.AktualniPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    PolickaHraciDesky[tah.AktualniPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                    }
                    if (tah.AktualniPolicko.Souradnice.Radek > tah.BudouciPolicko.Souradnice.Radek)
                    {
                        if (tah.AktualniPolicko.Souradnice.Sloupec < tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.AktualniPolicko.Souradnice.Sloupec + 1; i <= tah.BudouciPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                        if (tah.AktualniPolicko.Souradnice.Sloupec > tah.BudouciPolicko.Souradnice.Sloupec)
                        {
                            for (int i = tah.BudouciPolicko.Souradnice.Sloupec + 1; i <= tah.AktualniPolicko.Souradnice.Sloupec - 1; i++)
                            {
                                if (PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka != null)
                                {
                                    PolickaHraciDesky[tah.BudouciPolicko.Souradnice.Radek + pricist, i].Figurka = null;
                                }
                                pricist++;
                            }
                            pricist = 1;
                        }
                    }
                }
            }
            // Odstraní figurku z aktualního políčka, která byla přiřazena budoucímu políčku
            tah.AktualniPolicko.Figurka = null;
        }

        static List<Policko> polickaSModrymaFigurkama;
        static List<Policko> polickaSCervenymaFigurkama;

        /// <summary>
        /// Vrátí políčka s figurkami stejné barvy
        /// </summary>
        /// <returns></returns>
        public static Policko[] ZjistiPolickaSFigurkami(bool modra)
        {
            ZjistiPolickaSFigurkami();

            if (modra)
            {
                return polickaSModrymaFigurkama.ToArray();
            }
            else
            {
                return polickaSCervenymaFigurkama.ToArray();
            }
        }

        /// <summary>
        /// Vrátí políčka se všemi figurkami
        /// </summary>
        /// <returns></returns>
        public static Policko[] ZjistiPolickaSFigurkami()
        {
            polickaSModrymaFigurkama = new List<Policko>();
            polickaSCervenymaFigurkama = new List<Policko>();
            foreach (Policko policko in PolickaHraciDesky)
            {
                if (policko.Figurka != null)
                {
                    if (policko.Figurka.Modra)
                        polickaSModrymaFigurkama.Add(policko);
                    else
                        polickaSCervenymaFigurkama.Add(policko);
                }
            }
            List<Policko> vrat = new List<Policko>(polickaSModrymaFigurkama);
            vrat.AddRange(polickaSCervenymaFigurkama);
            return vrat.ToArray();
        }

        static List<Figurka> zalohovaneFigurky;

        /// <summary>
        /// Zálohuje stav všech figurek
        /// </summary>
        public static void ZalohujStav()
        {
            zalohovaneFigurky = new List<Figurka>();
            foreach (Policko polickoSFigurkou in ZjistiPolickaSFigurkami())
            {
                zalohovaneFigurky.Add(polickoSFigurkou.Figurka);
            }
        }
        /// <summary>
        /// Obnoví stav šachových figurek
        /// </summary>
        public static void ObnovStav()
        {
            foreach (Policko policko in PolickaHraciDesky)
            {
                policko.Figurka = null;
            }

            foreach (Figurka zalohovanaFigurka in zalohovaneFigurky)
            {
                if (zalohovanaFigurka is Kamen)
                {
                    if (zalohovanaFigurka.Modra == true)
                    {
                        PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Figurka = new Kamen(true, PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Souradnice);
                    }
                    else
                    {
                        PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Figurka = new Kamen(false, PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Souradnice);
                    }
                }
                else
                {
                    if (zalohovanaFigurka.Modra == true)
                    {
                        PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Figurka = new Dama(true, PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Souradnice);
                    }
                    else
                    {
                        PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Figurka = new Dama(false, PolickaHraciDesky[zalohovanaFigurka.Souradnice.Radek, zalohovanaFigurka.Souradnice.Sloupec].Souradnice);
                    }
                }

            }
        }
    }
}

